--8<-- "./README.md:3"

## Why attrs?

Attrs is the original python data class without boilerplate with a huge following. It
comes with features not found in the stdlib dataclasses, like keyword only arguments and
slotted classes, that won't be available until Python 3.10

It's so similar to dataclasses that also makes it the perfect candidate to test the
xsdata's plugin hooks.
